@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -104,14 +104,6 @@ int Basic_buffer::characters( const int line ) const
   }
 
 
-bool Basic_buffer::compare_lines( const int line1, const int line2 ) const
-  {
-  if( line1 < 0 || line1 >= lines() || line2 < 0 || line2 >= lines() )
-    return false;
-  return ( data[line1] == data[line2] );
-  }
-
-
 bool Basic_buffer::one_character() const
   {
   return ( data[0].size() == 1 &&
@@ -418,7 +410,7 @@ Point Basic_buffer::eop( const Point & p ) const
 int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
                                              const bool force ) const
   {
-  int ch1 = (*this)[p];
+  const int ch1 = (*this)[p];
   if( ch1 < 0 ) return 0;
   unsigned char ch2;
   const bool forward_orig = forward;
@@ -458,11 +450,7 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
     return 0;
     }
 
-  {
-  Point pt = p;		// no match if delimiter is escaped
-  if( ppgetc( pt ) == '\\' )
-    { Point pt2 = pt; if( ppgetc( pt2 ) != '\\' ) return -1; }
-  }
+  if( pisescaped( p ) ) return -1;	// no match if delimiter is escaped
 
   Point p1 = p;
   int level = 0;	// nesting level of delimiters
@@ -482,6 +470,13 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
           if( pngetc( pt ) == '\'' ) p1 = pt;
           continue;
           }
+        else if( ch == '/' )		// ignore delimiters in /**/ comments
+          {
+          Point pt = p1;
+          if( pngetc( pt ) == '*' && pngetc( pt ) >= 0 )
+            { find_text( pt, "*/" ); pprev( pt ); p1 = pt; }
+          continue;
+          }
         }
 
       if( ch == '\\' ) pnext( p1 );	// ignore escaped characters
@@ -493,9 +488,7 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
       const int ch = ppgetc( p1 ); if( ch < 0 ) break;
       if( !quote )
         {
-        Point pt = p1;
-        if( ppgetc( pt ) == '\\' )
-          { Point pt2 = pt; if( ppgetc( pt2 ) != '\\' ) { p1 = pt; continue; } }
+        if( pisescaped( p1 ) ) { ppgetc( p1 ); continue; }
         if( ch == ch2 ) { if( --level < 0 ) { p = p1; return +1; } }
         else if( ch == ch1 ) { ++level; continue; }
         else if( ch == '\'' )		// ignore single-quoted characters
@@ -504,13 +497,18 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
           if( ppgetc( pt ) == '\'' ) p1 = pt;
           continue;
           }
+        else if( ch == '/' )		// ignore delimiters in /**/ comments
+          {
+          Point pt = p1;
+          if( ppgetc( pt ) == '*' ) { rfind_text( pt, "/*" ); p1 = pt; }
+          continue;
+          }
         }
 
       if( ch == '"' && ch1 != '\'' )
         {
-        Point pt = p1;
-        if( ppgetc( pt ) == '\\' )	// ignore escaped quotes
-          { Point pt2 = pt; if( ppgetc( pt2 ) != '\\' ) { p1 = pt; continue; } }
+        // ignore escaped double quotes
+        if( pisescaped( p1 ) ) { ppgetc( p1 ); continue; }
         quote = !quote;
         }
       }
