@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,7 +74,8 @@ public:
 
   bool blank( const int line ) const;	// true if line is blank
   int  characters( const int line ) const;
-  bool compare_lines( const int line1, const int line2 ) const;
+  bool compare_lines( const int line1, const int line2 ) const
+    { return ( data[line1] == data[line2] ); }
   bool empty() const { return ( data.size() == 1 && data[0].empty() ); }
   int  lines() const { return data.size(); }
   int  last_line() const { return lines() - 1; }
@@ -105,6 +106,9 @@ public:
 
   bool pisbow( const Point & p ) const;
   bool piseow( const Point & p ) const;
+  bool pisescaped( Point p ) const
+    { bool escaped = false; while( ppgetc( p ) == '\\' ) escaped = !escaped;
+      return escaped; }
   bool pisvalid( const Point & p ) const
     { return ( ( p.col >= 0 && p.col < characters( p.line ) ) || p == eof() ); }
 
