@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@ public:
   Point pcursor;	// buffer coordinates of current buffer character
 
   explicit Buffer_handle( Buffer & buf, const int line = 0, const int col = 0 )
-    : bufferp_( &buf ), top_left( 0, 0 ), cursor( line, col ),
-      pointer( cursor ), pcursor( cursor ) {}
+    : bufferp_( &buf ), top_left( 0, 0 ), cursor( line, col )
+    { pointer = buf.to_pointer( cursor, pcursor ); }
 
   Buffer & buffer() { return *bufferp_; }
   const Buffer & buffer() const { return *bufferp_; }
