@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -586,9 +586,20 @@ int map_to_byte( const int code )
     case 0x209B: return 's';	// latin subscript small letter s
     case 0x209C: return 't';	// latin subscript small letter t
     case 0x20AC: return 0xA4;	// euro sign
+    case 0x2212: return '-';	// minus sign
     case 0x2213: return 0xB1;	// minus-or-plus sign
     case 0x2215: return '/';	// division slash
+    case 0x2216: return '\\';	// set minus
+    case 0x2217: return '*';	// asterisk operator
+    case 0x2218: return 0xB0;	// ring operator
     case 0x2219: return 0xB7;	// bullet operator
+    case 0x2223: return '|';	// divides
+    case 0x2236: return ':';	// ratio
+    case 0x223C: return '~';	// tilde operator
+    case 0x227A: return '<';	// precedes
+    case 0x227B: return '>';	// succeeds
+    case 0x22B0: return '<';	// precedes under relation
+    case 0x22B1: return '>';	// succeeds under relation
     case 0x22C5: return 0xB7;	// dot operator
     case 0x27E8: return '<';	// mathematical left angle bracket
     case 0x27E9: return '>';	// mathematical right angle bracket
@@ -600,8 +611,7 @@ int map_to_byte( const int code )
 //  if( code >= 0x0300 && code <= 0x036F ) return 256;	// combining diacritical marks
   if( ( code >= 0x2000 && code <= 0x200B ) ||
       code == 0x202F || code == 0x205F || code == 0x3000 ) return ' ';
-  if( ( code >= 0x2010 && code <= 0x2013 ) || code == 0x2043 || code == 0x2212 )
-    return '-';
+  if( ( code >= 0x2010 && code <= 0x2013 ) || code == 0x2043 ) return '-';
   if( ( code >= 0x2018 && code <= 0x201B ) || code == 0x2032 ) return '\'';
   if( ( code >= 0x201C && code <= 0x201F ) || code == 0x2033 || code == 0x2036 )
     return '"';
@@ -671,6 +681,12 @@ const char * map_to_string( const int code )
     case 0x2048: return "?!";
     case 0x2049: return "!?";
     case 0x2057: return "''''";
+    case 0x2122: return "TM";	// trade mark sign
+    case 0x2237: return "::";	// proportion
+    case 0x2264: return "<=";	// less-than or equal to
+    case 0x2265: return ">=";	// greater-than or equal to
+    case 0x227C: return "<=";	// precedes or equal to
+    case 0x227D: return ">=";	// succeeds or equal to
     }
   return 0;
   }
