@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,9 @@
 */
 
 #include <cctype>
+#if defined(__CYGWIN__)
+#include <clocale>
+#endif
 #include <csignal>
 #include <cstdio>
 #include <cstdlib>
@@ -38,10 +41,10 @@
 
 namespace {
 
-const char * const     Program_name = "GNU Moe";
+const char * const     Program_name = "GNU moe";
 const char * const     program_name = "moe";
 const char * const config_file_name = "moerc";
-const char * const     program_year = "2016";
+const char * const     program_year = "2017";
 const char * invocation_name = 0;
 
 
@@ -50,16 +53,19 @@ void show_help()
   std::printf( "%s is a powerful, 8-bit clean, console text editor for ISO-8859 and\n"
                "ASCII character encodings. It has a modeless, user-friendly interface,\n"
                "online help, multiple windows, unlimited undo/redo capability, unlimited\n"
-               "line length, global search/replace (on all buffers at once), block\n"
-               "operations, automatic indentation, word wrapping, file name completion,\n"
-               "directory browser, duplicate removal from prompt histories, delimiter\n"
-               "matching, text conversion from/to UTF-8, romanization, etc.\n", Program_name );
+               "line length, unlimited buffers, global search/replace (on all buffers at\n"
+               "once), block operations, automatic indentation, word wrapping, file name\n"
+               "completion, directory browser, duplicate removal from prompt histories,\n"
+               "delimiter matching, text conversion from/to UTF-8, romanization, etc.\n"
+               "\nMoe can easily edit thousands of files at the same time.\n", Program_name );
   std::printf( "\nUsage: %s [global_options] [[+line[,col]] file_name [file_options]]...\n", invocation_name );
   std::printf( "\n'global_options' are a mix of editor options and default file_options.\n"
                "Most long option names have a negative form '--backup' '--no-backup'.\n"
                "\nEach file name may be preceded by '+line[,column]' to start the cursor\n"
                "at the specified line and, optionally, column. 'line' and 'column' are\n"
                "applied to subsequent files until new values are specified for them.\n"
+               "\n'-' used as a file name argument means standard input.\n"
+               "Directories are recursively descended into.\n"
                "\nEditor options:\n"
                "  -h, --help               display this help and exit\n"
                "  -V, --version            output version information and exit\n"
@@ -201,8 +207,7 @@ void RC::show_error( const char * const msg, const int errcode,
   if( msg && msg[0] )
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 )
-      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
     std::fputc( '\n', stderr );
     }
   if( help )
@@ -214,6 +219,10 @@ void RC::show_error( const char * const msg, const int errcode,
 int main( const int argc, const char * const argv[] )
   {
   invocation_name = argv[0];
+#if defined(__CYGWIN__)
+  // set an 8-bit "C" locale in Cygwin so that ncurses can show chars > 127
+  std::setlocale( LC_ALL, "C.ISO-8859-15" );
+#endif
 
   int retval = RC::read_options( argc, argv );
   if( retval )
@@ -234,7 +243,8 @@ int main( const int argc, const char * const argv[] )
     }
   if( retval ) return retval;
 
-  if( !Screen::init() ) { RC::show_error( "Screen too small." ); return 1; }
+  if( !Screen::init() )
+    { RC::show_error( "Screen too small (min size 24 x 80)." ); return 1; }
   set_signals();
 
   char buf[88];
