@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,8 @@ bool tilde_expansion( std::string & name );
 bool validate_filename( std::string & name );
 
 
-void help_menu( const int abort_key1, const int abort_key2 = 3 );
+void help_menu( const int abort_key1, const int abort_key2,
+                const int abort_key3 );
 
 
 void options_menu( Buffer & buffer, const int abort_key );
