@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -192,9 +192,9 @@ int Menu::bufhandle_menu( int current, const int abort_key )
       else switch( Screen::convert_key( key ) )
         {
         case Screen::key_up   :
-          if( current >= columns ) current -= columns; break;
+          if( current >= columns ) { current -= columns; } break;
         case Screen::key_down :
-          if( current + columns < entries ) current += columns; break;
+          if( current + columns < entries ) { current += columns; } break;
         case Screen::key_left : if( current > 0 ) --current; break;
         case Screen::key_right: if( current < entries - 1 ) ++current; break;
         case Screen::key_ppage:
@@ -248,7 +248,7 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 
   if( entries == 1 || ( entries == 2 && name_vector[0] == ".." ) )
     { name = dirname + name_vector.back(); append_slash_if_dir( name );
-    return true; }
+      return true; }
 
   int max_width = 0;
   for( int i = 0; i < entries; ++i )
@@ -289,11 +289,13 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
                  else switch( Screen::convert_key( key ) )
                    {
                    case Screen::key_up   :
-                     if( current >= columns ) current -= columns; break;
+                     if( current >= columns ) { current -= columns; } break;
                    case Screen::key_down :
-                     if( current + columns < entries ) current += columns; break;
+                     if( current + columns < entries ) current += columns;
+                     break;
                    case Screen::key_left : if( current > 0 ) --current; break;
-                   case Screen::key_right: if( current < entries - 1 ) ++current; break;
+                   case Screen::key_right:
+                     if( current < entries - 1 ) { ++current; } break;
                    case Screen::key_ppage:
                      for( int i = 0; i < lines && current >= columns; ++i )
                        current -= columns;
@@ -320,7 +322,7 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 // 'name' is cleared if aborted.
 //
 int Menu::get_filename( const std::string & prompt, std::string & name,
-                             const int abort_key )
+                        const int abort_key )
   {
   static std::vector< std::string > file_history;
 
