@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ const char * help_line[] = {
   " ^[O Offset             ^QU update (C)              ^Y   Delete line",
   " ^[B Beg of block                                   ^OC  Center line",
   " ^[K End of block       @bINFO@b                        ^ON  Change buffer name",
-  " ^[F Match pair ->      ^H   Show help              ^OR  Repaint screen",
+  " ^[F Match pair ->      ^A   Show help              ^OR  Repaint screen",
   " ^[G Match pair <-      ^[I  Show character info    ^OS  Split window",
   " ^[D Center cursor      ^[T  Show UTF-8 code        ^Q@bF2@b Save named buffers",
   "                        ^Sn  Show LE multibyte",
@@ -74,7 +74,7 @@ const char * help_line[] = {
   " ",
   " ^[X means Alt-X or Esc-X    ^X means Control-X",
   " ",
-  " See manual (moe.info) for a complete explanation of Moe's commands.",
+  " See manual (moe.info) for a complete explanation of moe's commands.",
   "",
   " Help Screen: Search             PAGE_DN next/PAGE_UP prev",
   " ",
@@ -228,7 +228,8 @@ void show_help_screen( const int current )
 } // end namespace Menu
 
 
-void Menu::help_menu( const int abort_key1, const int abort_key2 )
+void Menu::help_menu( const int abort_key1, const int abort_key2,
+                      const int abort_key3 )
   {
   static int current = 0;
   int old = -1;				// make old != current
@@ -243,15 +244,15 @@ void Menu::help_menu( const int abort_key1, const int abort_key2 )
       Screen::move_to( Point( 0, Screen::width() - 1 ) );
       }
     const int key = Screen::wait_kbhit( 1 );	// show clock on line 0 only
-    if( key == 3 || key == abort_key1 || key == abort_key2 ) break;	// ^C
+    if( key == 3 || key == abort_key1 || key == abort_key2 ||
+        key == abort_key3 ) break;				// ^C
     switch( Screen::convert_key( key ) )
       {
       case Screen::key_down :
       case Screen::key_npage:
-        if( current + 2 < help_index.size() ) ++current; break;
+        if( current + 2 < help_index.size() ) { ++current; } break;
       case Screen::key_up   :
-      case Screen::key_ppage:
-        if( current > 0 ) --current; break;
+      case Screen::key_ppage: if( current > 0 ) --current; break;
       case Screen::key_home : current = 0; break;
       case Screen::key_end  : current = help_index.size() - 2; break;
       default: break;
