@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -274,7 +274,7 @@ struct Init_menu
   Init_menu()
     {
     current = 0;
-    for( entries = 0; table[entries].ch; ++entries ) ;
+    for( entries = 0; table[entries].ch; ++entries );
     height_ = ( entries + columns - 1 ) / columns;
     }
   } dummy;
@@ -346,15 +346,18 @@ void Menu::options_menu( Buffer & buffer, const int abort_key )
                  else switch( Screen::convert_key( key ) )
                    {
                    case Screen::key_up   :
-                     if( current >= columns ) current -= columns; break;
+                     if( current >= columns ) { current -= columns; } break;
                    case Screen::key_down :
-                     if( current + columns < entries ) current += columns; break;
+                     if( current + columns < entries ) current += columns;
+                     break;
                    case Screen::key_left : if( current > 0 ) --current; break;
-                   case Screen::key_right: if( current < entries - 1 ) ++current; break;
+                   case Screen::key_right:
+                     if( current < entries - 1 ) { ++current; } break;
                    case Screen::key_ppage:
-                     while( current >= columns ) current -= columns; break;
+                     while( current >= columns ) { current -= columns; } break;
                    case Screen::key_npage:
-                     while( current + columns < entries ) current += columns; break;
+                     while( current + columns < entries ) current += columns;
+                     break;
                    case Screen::key_home : current = 0; break;
                    case Screen::key_end  : current = entries - 1; break;
                    default: valid_key = false;
