@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,14 +15,19 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <algorithm>
 #include <cctype>
 #include <cerrno>
 #include <climits>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
+#include <list>
 #include <string>
 #include <vector>
+#include <dirent.h>
+#include <unistd.h>
+#include <sys/stat.h>
 
 #include "arg_parser.h"
 #include "buffer.h"
@@ -83,11 +88,12 @@ enum Optcode
   auto_unmark = 'u', backup = 'b', no_backup = 'B', /*beep = 'p',*/
   exit_ask = 'e', ignore_case = 'i', indent_step = 'n', keep_lines = 'k',
   max_windows = 'm', orphan_extra= '1', rectangle_mode = 'x',
-  search_wrap = 's', smart_home = 'H', auto_indent = 'a', lmargin = 'l',
-  rmargin = 'r', overwrite = 'O', read_only = 'o', word_wrap = 'w',
+  search_wrap = 's', smart_home = 'H',
+  auto_indent = 'a', lmargin = 'l', rmargin = 'r', overwrite = 'O',
+  read_only = 'o', word_wrap = 'w',
   no_auto_unmark = 256, /*no_beep,*/ no_exit_ask, no_ignore_case,
-  no_rectangle_mode, no_search_wrap, no_smart_home, no_auto_indent,
-  no_overwrite, no_read_only, no_word_wrap
+  no_rectangle_mode, no_search_wrap, no_smart_home,
+  no_auto_indent, no_overwrite, no_read_only, no_word_wrap
   };
 
 const Arg_parser::Option options[] =
@@ -183,20 +189,23 @@ bool set_option_from_code( const int code, const std::string & arg,
     case no_ignore_case:    editor_options_.ignore_case = false; break;
     case indent_step:
       if( !parse_int( arg, n ) ) errcode = 1;
-      else if( !editor_options_.set_indent_step( n ) ) errcode = 2; break;
+      else if( !editor_options_.set_indent_step( n ) ) errcode = 2;
+      break;
     case keep_lines:
       if( !parse_int( arg, n ) ) errcode = 1;
-      else if( !editor_options_.set_keep_lines( n ) ) errcode = 2; break;
+      else if( !editor_options_.set_keep_lines( n ) ) errcode = 2;
+      break;
     case max_windows:
       if( !parse_int( arg, n ) ) errcode = 1;
-      else if( !editor_options_.set_max_windows( n ) ) errcode = 2; break;
+      else if( !editor_options_.set_max_windows( n ) ) errcode = 2;
+      break;
     case orphan_extra:      editor_options_.orphan_extra = true; break;
     case rectangle_mode:    editor_options_.rectangle_mode = true; break;
     case no_rectangle_mode: editor_options_.rectangle_mode = false; break;
-    case smart_home:        editor_options_.smart_home = true; break;
-    case no_smart_home:     editor_options_.smart_home = false; break;
     case search_wrap:       editor_options_.search_wrap = true; break;
     case no_search_wrap:    editor_options_.search_wrap = false; break;
+    case smart_home:        editor_options_.smart_home = true; break;
+    case no_smart_home:     editor_options_.smart_home = false; break;
 
     case auto_indent:
     case no_auto_indent:
@@ -209,12 +218,12 @@ bool set_option_from_code( const int code, const std::string & arg,
     case lmargin:
       if( !parse_int( arg, n ) ) errcode = 1;
       else if( !Buffer::Options().set_lmargin( n - 1 ) ) errcode = 2;
-      else file_options.add_option( code, n - 1 ); break;
+      else file_options.add_option( code, n - 1 );
       break;
     case rmargin:
       if( !parse_int( arg, n ) ) errcode = 1;
       else if( !Buffer::Options().set_rmargin( n - 1 ) ) errcode = 2;
-      else file_options.add_option( code, n - 1 ); break;
+      else file_options.add_option( code, n - 1 );
       break;
     default: std::fprintf( stderr, "%sinternal error: uncaught option.\n", msg );
              return false;
@@ -284,6 +293,87 @@ void apply_regex_options( Buffer & buffer )
     }
   }
 
+
+// Depth first. Files first in each directory. Load regular files only.
+// Ignore backups '*~', object files '*.o' and symbolic links.
+bool add_handles_recursively( std::string name, const int line, const int col,
+                              const File_options & file_options,
+                              bool & first_post, bool & read_error_found )
+  {
+  while( !name.empty() && name[name.size()-1] == '/' )
+    name.resize( name.size() - 1 );		// reject "/", "//", etc.
+  if( name.empty() ) return false;
+  while( name.size() > 2 && name[0] == '.' && name[1] == '/' )
+    name.erase( 0, 2 );				// remove leading ./
+  struct stat st;
+  if( stat( name.c_str(), &st ) != 0 || !S_ISDIR( st.st_mode ) )
+    return false;
+  std::list< std::string > dirnames;		// only directory names here
+  dirnames.push_back( name );
+  while( !dirnames.empty() )
+    {
+    const std::string dirname = dirnames.front();
+    dirnames.pop_front();
+    DIR * const dirp = opendir( dirname.c_str() );
+    if( !dirp ) { read_error_found = true; continue; }
+    std::vector< std::string > name_vector;
+    const bool isdot = ( dirname == "." );
+    while( true )
+      {
+      const struct dirent * const entryp = readdir( dirp );
+      if( !entryp ) { closedir( dirp ); break; }
+      std::string tmp( entryp->d_name );
+      if( tmp == "." || tmp == ".." || tmp.empty() ||
+          tmp[tmp.size()-1] == '~' ||
+          ( tmp.size() > 2 && tmp.compare( tmp.size() - 2, 2, ".o" ) == 0 ) )
+        continue;
+      if( !isdot ) tmp = dirname + "/" + tmp;
+      name_vector.push_back( tmp );
+      }
+    if( name_vector.empty() ) continue;
+    if( name_vector.size() > 1 )
+      std::sort( name_vector.begin(), name_vector.end() );
+    std::list< std::string > tmp_list;		// subdirs temporary list
+    for( unsigned i = 0; i < name_vector.size(); )
+      {
+      const unsigned dot = name_vector[i].rfind( '.' );
+      const unsigned slash = name_vector[i].rfind( '/' );
+      const unsigned size = name_vector[i].size();
+      const unsigned j = i++;
+      if( dot < size - 1 && dot > 0 && ( slash >= size || slash + 1 < dot ) &&
+          ( !std::isdigit( name_vector[j][dot-1] ) ||
+            !std::isdigit( name_vector[j][dot+1] ) ) )
+        while( i < name_vector.size() &&
+               name_vector[j].compare( 0, dot + 1, name_vector[i],
+                                       0, dot + 1 ) == 0 &&
+               name_vector[i].rfind( '.' ) == dot ) ++i;
+      for( unsigned k = i; k > j; --k )		// reverse sort by extension
+        {
+        if( lstat( name_vector[k-1].c_str(), &st ) != 0 ) continue;
+        if( S_ISDIR( st.st_mode ) ) tmp_list.push_back( name_vector[k-1] );
+        else if( S_ISREG( st.st_mode ) )
+          {
+          try {
+            const int h = Bufhandle_vector::find_or_add_handle(
+                            &name_vector[k-1], -1, line, col );
+            apply_file_options( Bufhandle_vector::handle( h ).buffer(),
+                                file_options );
+            }
+          catch( Buffer::Error e )
+            {
+            if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
+            std::fprintf( stderr, "warning: '%s': %s\n",
+                          name_vector[k-1].c_str(), e.msg );
+            read_error_found = true;
+            }
+          }
+        }
+      }
+    dirnames.splice( dirnames.begin(), tmp_list );	// prepend subdirs
+    }
+  return true;
+  }
+
 } // end namespace RC
 
 
@@ -433,6 +523,7 @@ int RC::process_options()
   bool first_post = true;
   bool non_regular_found = false;
   bool read_error_found = false;
+  bool stdin_used = false;
   while( argind < parserp->arguments() )  // Process files and file options
     {
     if( parserp->argument( argind )[0] == '+' )		// line number
@@ -452,16 +543,27 @@ int RC::process_options()
         }
       }
 //    else { line = 0; col = 0; }
-    Buffer * bufferp = 0;
     std::string name( parserp->argument( argind++ ) );
     Menu::tilde_expansion( name );
+    File_options file_options;
+    for( ; argind < parserp->arguments(); ++argind )
+      {						// Process file options
+      const int code = parserp->code( argind );
+      if( !code ) break;			// line number or file name
+      if( !set_option_from_code( code, parserp->argument( argind ),
+                                 file_options, first_post ? "\n" : "" ) )
+        return 1;
+      }
     bool can_read = false;
-    if( Menu::is_regular( name, &can_read ) || can_read )
+    const bool is_stdin = ( name == "-" );
+    if( is_stdin && ( stdin_used || isatty( fileno( stdin ) ) ) );
+      // ignore stdin if is repeated or is a terminal
+    else if( Menu::is_regular( name, &can_read ) || can_read )
       {
       try {
         const int i = Bufhandle_vector::find_or_add_handle( &name, -1, line,
                                                             col, can_read );
-        bufferp = &Bufhandle_vector::handle( i ).buffer();
+        apply_file_options( Bufhandle_vector::handle( i ).buffer(), file_options );
         }
       catch( Buffer::Error e )
         {
@@ -470,23 +572,14 @@ int RC::process_options()
         read_error_found = true;
         }
       }
-    else
+    else if( !add_handles_recursively( name, line, col, file_options,
+                                       first_post, read_error_found ) )
       {
       if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
       std::fprintf( stderr, "warning: '%s' is not a regular file\n", name.c_str() );
       non_regular_found = true;
       }
-    File_options file_options;
-    for( ; argind < parserp->arguments(); ++argind )
-      {						// Process file options
-      const int code = parserp->code( argind );
-      if( !code ) break;			// line number or file name
-      if( bufferp &&
-          !set_option_from_code( code, parserp->argument( argind ),
-                                 file_options, first_post ? "\n" : "" ) )
-        return 1;
-      }
-    if( bufferp ) apply_file_options( *bufferp, file_options );
+    if( is_stdin ) stdin_used = true;
     }
   // Add empty buffer if no files given or stdin is not a tty
   try { Bufhandle_vector::add_handle_if_pending_input_or_empty( line, col ); }
