@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
         if( j >= counter )
           {
           const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-          if( tmp == 0 ) break; if( tmp != 1 ) return 2;
+          if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
           }
         const int ch2 = buffer.pgetc( p );
         if( ch2 < 0 || !set.includes( ch2 ) ) return 1;
@@ -126,7 +126,7 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
         if( j >= counter )
           {
           const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-          if( tmp == 0 ) break; if( tmp != 1 ) return 2;
+          if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
           }
         const int ch2 = buffer.pgetc( p );
         if( ch2 < 0 || ( chr == 'w' ) != ISO_8859::isalnum_( ch2 ) )
@@ -145,7 +145,7 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
     if( j >= counter )
       {
       const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-      if( tmp == 0 ) break; if( tmp != 1 ) return 2;
+      if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
       }
     const int ch2 = buffer.pgetc( p );
     if( ch2 < 0 ||
