@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -76,7 +76,6 @@ void dummy_endwin() { endwin(); }
 
 void initialize_ncurses()
   {
-  std::atexit( dummy_endwin );
   initscr();			// initializes curses data structures
   raw();			// read a char at a time and disable signals
   keypad( stdscr, true );	// enables single value for function keys
@@ -90,11 +89,11 @@ void initialize_ncurses()
 inline void rep_addch( int n, const chtype ch )	// only for printable chars
   { for( ; n > 0; --n ) waddch( stdscr, ch ); }
 
-void out_raw_char( chtype ch, const chtype atr )
+void out_raw_char( unsigned char ch, chtype atr )
   {
-  if( ch < 32 ) ch = ( ch + '@' ) | A_UNDERLINE;
+  if( ch < 32 ) { ch += '@'; atr |= A_UNDERLINE; }
   else if( ch >= 0x7F && ch < 0xA0 )
-    ch = ( ch + '@' - 0x80 ) | A_REVERSE | A_UNDERLINE;
+    { ch = ( ch + '@' - 0x80 ); atr |= ( A_REVERSE | A_UNDERLINE ); }
   waddch( stdscr, ch | atr );
   }
 
@@ -234,13 +233,13 @@ const char * control_o_loop( int key )
     case '5': Window_vector::encode_ascii_utf8( &msg, true ); break;
     case '6': msg = Window_vector::decode_quoted_printable_utf8( true ); break;
     case '7': if( Window_vector::encode_ascii_utf8( &msg, false,
-                    last_key.compare_prev() ) ) last_key.unset(); break;
+                    last_key.compare_prev() ) ) { last_key.unset(); } break;
     case '8': msg = Window_vector::decode_quoted_printable_utf8( false,
                       last_key.compare_prev() ); break;
     case 'C': Window_vector::center_line(); break;
     case 'D': msg = Window_vector::remove_duplicate_lines(); break;
     case 'E': msg = Window_vector::remove_duplicate_lines( true ); break;
-    case 'F': msg = Window_vector::search( 6, true, "", true ); break;
+    case 'F': msg = Window_vector::search( 6, true, "", 2 ); break;
     case 'L': msg = Window_vector::change_case( false ); break;
     case 'N': msg = Window_vector::change_buffer_name(); break;
     case 'O': msg = Window_vector::remove_utf8_out_of_range(); break;
@@ -349,8 +348,8 @@ const char * user_control_char( const int abort_key )
   while( true )
     {
     key = show_message( prompt1, false, true );
-    if( key == 8 || key == KEY_F(1) )
-      { wait_kbhit(); Menu::help_menu( 8, KEY_F(1) ); }
+    if( key == 1 || key == 8 || key == KEY_F(1) )
+      { wait_kbhit(); Menu::help_menu( 1, 8, KEY_F(1) ); }
     else if( key == 3 || key == abort_key ) { wait_kbhit(); return 0; }	// ^C
     else if( key >= 256 || key == '\\' || std::isalnum( key ) ) break;
     else wait_kbhit();
@@ -428,7 +427,8 @@ bool Screen::init()
   {
   initialize_ncurses();
   getmaxyx( stdscr, height_, width_ );
-  if( height_ < 24 || width_ < 80 ) return false;
+  if( height_ < 24 || width_ < 80 ) { endwin(); return false; }
+  std::atexit( dummy_endwin );
   line_buf_size = width_ + 1;
   line_buf_ = new char[line_buf_size];
   clock_limit = 0;
@@ -564,8 +564,9 @@ int Screen::get_string( const std::string & prompt,
                    { key = -2; history.back() = name; }
                  }
                  break;
-      case 8        :						// ^H
-      case KEY_F(1) : Menu::help_menu( 8, KEY_F(1) ); break;
+      case 1:							// ^A
+      case 8:							// ^H
+      case KEY_F(1) : Menu::help_menu( 1, 8, KEY_F(1) ); break;
       case KEY_F(9) : if( Block::valid() )
                         {
                         std::string tmp;
@@ -798,6 +799,21 @@ int Screen::function_key( const int key )
   }
 
 
+const char * Screen::cut_filename( const std::string & filename,
+                                   const int used_size )
+  {
+  static std::string short_name;
+
+  const unsigned available_size = std::max( 0, width_ - used_size );
+  if( filename.size() <= available_size || filename.size() <= 3 )
+    return filename.c_str();
+  const unsigned pos = filename.size() + 3 - std::max( 4U, available_size );
+  short_name = "...";
+  short_name.append( filename, pos, filename.size() );
+  return short_name.c_str();
+  }
+
+
 int Screen::user_loop( const char * const version_msg )
   {
   show_message( version_msg );
@@ -828,8 +844,9 @@ int Screen::user_loop( const char * const version_msg )
       case 24: if( !Window_vector::close( false ) ) retval = 0; break;	// ^X
       case 25: Window_vector::delete_line(); break;		// ^Y
       case 27: msg = alt_key_loop( key ); break;		// Alt or Esc
-      case  8:							// ^H
-      case KEY_F(1) : Menu::help_menu( 8, KEY_F(1) ); break;
+      case 1:							// ^A
+      case 8:							// ^H
+      case KEY_F(1) : Menu::help_menu( 1, 8, KEY_F(1) ); break;
       case KEY_F(2) : msg = Window_vector::save_file( key ); break;
       case KEY_F(3) : msg = Window_vector::load_file( key ); break;
       case KEY_F(4) : if( !Window_vector::load( -1 ) ) retval = 3; break;
