@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,6 +74,7 @@ void show_status_lines( const Buffer * const bufp = 0 );
 
 Keys convert_key( const int key );
 int function_key( const int key );		// return F number or -1
+const char * cut_filename( const std::string & filename, const int used_size );
 int user_loop( const char * const version_msg );
 
 } // end namespace Screen
