@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -51,7 +51,8 @@ const char * already_being_edited( const std::string & name,
         {
         int bufsize = 0;
         char * const buf = Screen::line_buf( &bufsize );
-        snprintf( buf, bufsize, "File '%s' is already being edited", name.c_str() );
+        snprintf( buf, bufsize, "File '%s' is already being edited",
+                  Screen::cut_filename( name, 31 ) );
         return buf;
         }
   return 0;
@@ -321,7 +322,8 @@ const char * Window_vector::save_file( const int abort_key )
     Screen::show_status_lines( &buffer );
     int bufsize = 0;
     char * const buf = Screen::line_buf( &bufsize );
-    snprintf( buf, bufsize, "File '%s' saved", name.c_str() );
+    snprintf( buf, bufsize, "File '%s' saved",
+              Screen::cut_filename( name, 13 ) );
     return buf;
     }
   if( !read_only( buffer ) ) return "File not saved";
@@ -333,13 +335,13 @@ const char * Window_vector::save_file( const int abort_key )
 //
 int Window_vector::close( bool abort, const bool quiet )
   {
-  Buffer_handle & bh = data[curwin_].buffer_handle();
-  const bool last_handle = Bufhandle_vector::handles( bh.buffer() ) <= 1;
-  const bool modified = bh.buffer().modified();
-  const bool exit_ask = RC::editor_options().exit_ask && !quiet;
-
   if( !abort || !quiet )
     {
+    Buffer_handle & bh = data[curwin_].buffer_handle();
+    const bool last_handle = Bufhandle_vector::handles( bh.buffer() ) <= 1;
+    const bool modified = bh.buffer().modified();
+    const bool exit_ask = RC::editor_options().exit_ask && !quiet;
+
     if( abort && modified && last_handle )
       {
       int key = Screen::show_message( "Lose changes to this file ? (y/n/^C) ", true, true );
@@ -351,7 +353,7 @@ int Window_vector::close( bool abort, const bool quiet )
       if( read_only( bh.buffer() ) ) return -1;
       std::string name( bh.buffer().name() );
       if( exit_ask || name.empty() )
-        while( !Menu::get_filename( "Name of file to save (^C to abort): ", name ) ) ;
+        while( !Menu::get_filename( "Name of file to save (^C to abort): ", name ) );
       if( name.empty() ) return -1;
       try { if( !bh.buffer().save( &name ) ) return -1; }
       catch( Buffer::Error e )
@@ -377,7 +379,7 @@ int Window_vector::close_and_exit( const bool abort )
   if( key == 'y' || key == 'Y' )
     {
     prev();
-    while( data.size() && close( abort, true ) >= 0 ) ;
+    while( data.size() && close( abort, true ) >= 0 );
     }
   return data.size();
   }
@@ -439,7 +441,8 @@ const char * Window_vector::add_char( const int key, const bool force )
       {
       case ' ': w.move_vertical( w.height() - 2 ); return 0;
       case '/': return search( 6 );				// ^F
-      case 'n': return search( 7, true );			// ^G
+      case 'n': return search( 7, true, "", 0 );		// ^G -->
+      case 'N': return search( 7, true, "", 1 );		// ^G <--
       }
     read_only( w.buffer() );
     return 0;
@@ -975,29 +978,30 @@ const char * Window_vector::remove_duplicate_lines( const bool back )
       read_only( buffer ) ) return 0;
 
   bool change = false;
+  const int first_line = Block::begin().line + ( Block::begin().col > 0 );
+  int last_line = std::min( Block::end().line, buffer.lines() ) - 1;
   if( back )
     {
-    int first_line = Block::begin().line;
-    if( Block::begin().col > 0 ) ++first_line;
-    for( int line = Block::end().line - 1; line > first_line; --line )
-      for( Point p( line - 1, 0 ); p.line >= first_line; --p.line )
-        if( buffer.compare_lines( line, p.line ) )
+    for( int line1 = last_line; line1 > first_line; --line1 )
+      for( int line2 = line1 - 1; line2 >= first_line; --line2 )
+        if( buffer.compare_lines( line1, line2 ) )
           {
           if( change ) buffer.force_append(); else change = true;
+          Point p( line2, 0 );
           buffer.pdell( p );
-          --line;
+          --line1;			// adjust current line
           }
     }
   else
     {
-    int line = Block::begin().line;
-    if( Block::begin().col > 0 ) ++line;
-    for( ; line < Block::end().line - 1; ++line )
-      for( Point p( Block::end().line - 1, 0 ); p.line > line; --p.line )
-        if( buffer.compare_lines( line, p.line ) )
+    for( int line1 = first_line; line1 < last_line; ++line1 )
+      for( int line2 = last_line; line2 > line1; --line2 )
+        if( buffer.compare_lines( line1, line2 ) )
           {
           if( change ) buffer.force_append(); else change = true;
+          Point p( line2, 0 );
           buffer.pdell( p );
+          --last_line;
           }
     }
   if( !change ) return "No duplicate lines in block";
@@ -1123,16 +1127,17 @@ const char * Window_vector::search_word( const int abort_key )
   }
 
 
+// 'toggle' reverses direction; 1 for this call, 2 permanently
 const char * Window_vector::search( const int abort_key, const bool again,
                                     const std::string & s_ini,
-                                    const bool toggle )
+                                    const int toggle )
   {
   static std::vector< std::string > search_history;
   static std::vector< std::string > replace_history;
   static std::vector< std::string > options_history;
   static std::string search_string;
   static std::string replace_string;
-  static bool backward = false;
+  static bool backward_opt = false;
   static bool block = false;
   static bool global = false;
   static bool icase = false;
@@ -1158,7 +1163,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
     options_history.push_back( std::string() );
     size = Screen::get_string( prompt, options_history, abort_key );
     if( size < 0 ) return 0;
-    backward = false; block = false; global = false; replace = false;
+    backward_opt = false; block = false; global = false; replace = false;
     icase = RC::editor_options().ignore_case;
     if( size > 0 )
       {
@@ -1166,7 +1171,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
       for( unsigned i = 0; i < options.size(); ++i )
         switch( ISO_8859::toupper( options[i] ) )
           {
-          case 'B': backward = true; break;
+          case 'B': backward_opt = true; break;
           case 'G': global = true; break;
           case 'I': icase = true; break;
           case 'K': block = true; break;
@@ -1185,7 +1190,12 @@ const char * Window_vector::search( const int abort_key, const bool again,
       if( len > 0 ) replace_string = replace_history.back();
       }
     }
-  if( toggle ) backward = !backward;
+  bool backward = backward_opt;
+  switch( toggle )			// leave backward as-is by default
+    {
+    case 2: backward_opt = !backward_opt;	// toggle permanently
+    case 1: backward = !backward;		// toggle this call
+    }
 
   Point p = curwin().pointer();			// search point
   if( block )
