@@ -1,5 +1,5 @@
-/*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2016 Antonio Diaz Diaz.
+/*  GNU moe - My Own Editor
+    Copyright (C) 2005-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -65,6 +65,6 @@ const char * copyright_update();
 const char * search_word( const int abort_key );
 const char * search( const int abort_key, const bool again = false,
                      const std::string & s_ini = "",
-                     const bool toggle = false );
+                     const int toggle = 0 );
 
 } // end namespace Window_vector
